@@ -15,7 +15,7 @@
 # limitations under the License.
 # ******************************************************************************
 """
- CIFAR10 model training script
+Training script for CIFAR10 models.
 """
 
 # System imports
@@ -33,7 +33,15 @@ from cnn2snn import load_quantized_model
 
 
 def get_rescaled_data_set(a, b):
+    """ Loads and rescales CIFAR10 dataset.
 
+    Args:
+        a (int): rescale factor
+        b (int): rescale bias
+
+    Returns:
+        tuple: train data, train labels, test data and test labels
+    """
     #The data, shuffled and split between train and test sets
     (x_train, y_train), (x_test, y_test) = cifar10.load_data()
 
@@ -42,9 +50,6 @@ def get_rescaled_data_set(a, b):
     y_train = to_categorical(y_train, 10) * 2 - 1
     y_test = to_categorical(y_test, 10) * 2 - 1
 
-    x_train = x_train.reshape(x_train.shape[0], 32, 32, 3)
-    x_test = x_test.reshape(x_test.shape[0], 32, 32, 3)
-
     x_train = x_train.astype('float32')
     x_test = x_test.astype('float32')
 
@@ -56,6 +61,15 @@ def get_rescaled_data_set(a, b):
 
 
 def compile_model(model, learning_rate):
+    """ Compiles the model.
+
+    Args:
+        model (tf.Keras.Model): the model to compile
+        learning_rate (float): the learning rate
+
+    Returns:
+        tf.Keras.Model: the compiled model
+    """
     # Initialize optimizer
     opt = Adam(lr=learning_rate)
 
@@ -66,6 +80,17 @@ def compile_model(model, learning_rate):
 
 
 def train_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
+    """ Trains the model.
+
+    Args:
+        model (tf.Keras.Model): the model to train
+        x_train (numpy.ndarray): train data
+        y_train (numpy.ndarray): train labels
+        x_test (numpy.ndarray): test data
+        y_test (numpy.ndarray): test labels
+        batch_size (int): the batch size
+        epochs (int): the number of epochs
+    """
 
     callbacks = []
 
@@ -93,16 +118,28 @@ def train_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
 
     training_data = datagen.flow(x_train, y_train, batch_size=batch_size)
 
-    history = model.fit(training_data,
-                        steps_per_epoch=len(x_train) / batch_size,
-                        epochs=epochs,
-                        verbose=1,
-                        validation_data=(x_test, y_test),
-                        callbacks=callbacks)
+    model.fit(training_data,
+              steps_per_epoch=len(x_train) / batch_size,
+              epochs=epochs,
+              verbose=1,
+              validation_data=(x_test, y_test),
+              callbacks=callbacks)
 
 
 def tune_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
+    """ Tunes the model.
 
+    Similar to train but with a lower learning rate.
+
+    Args:
+        model (tf.Keras.Model): the model to train
+        x_train (numpy.ndarray): train data
+        y_train (numpy.ndarray): train labels
+        x_test (numpy.ndarray): test data
+        y_test (numpy.ndarray): test labels
+        batch_size (int): the batch size
+        epochs (int): the number of epochs
+    """
     # Compile model
     model = compile_model(model, 1e-4)
 
@@ -114,17 +151,23 @@ def tune_model(model, x_train, y_train, x_test, y_test, batch_size, epochs):
                        restore_best_weights=True)
     callbacks.append(es)
 
-    history = model.fit(x_train,
-                        y_train,
-                        batch_size=batch_size,
-                        epochs=epochs,
-                        verbose=1,
-                        validation_data=(x_test, y_test),
-                        callbacks=callbacks)
+    model.fit(x_train,
+              y_train,
+              batch_size=batch_size,
+              epochs=epochs,
+              verbose=1,
+              validation_data=(x_test, y_test),
+              callbacks=callbacks)
 
 
 def evaluate_model(model, x_test, y_test):
+    """ Evaluates model performances.
 
+    Args:
+        model (tf.Keras.Model): the model to evaluate
+        x_test (numpy.ndarray): evaluation data
+        y_test (numpy.ndarray): evaluation labels
+    """
     # Compile model
     model = compile_model(model, 1e-4)
 
@@ -133,6 +176,8 @@ def evaluate_model(model, x_test, y_test):
 
 
 def main():
+    """ Entry point for script and CLI usage.
+    """
     parser = argparse.ArgumentParser()
     parser.add_argument("-m",
                         "--model",
