@@ -35,11 +35,10 @@ def vgg_cifar10(input_shape=(32, 32, 3),
                 weight_quantization=0,
                 activ_quantization=0,
                 input_weight_quantization=None):
-    """Instantiates a vgg-like model for the "Cifar-10" example.
-    This model is based on the vgg architecture, mainly with fewer layers.
+    """Instantiates a VGG-like model for the "CIFAR-10" example.
+    This model is based on the VGG architecture, mainly with fewer layers.
     The weights and activations are quantized such that it can be converted into
     an Akida model.
-    This architecture is inspired by vgg.
 
     Args:
         input_shape (tuple): input shape tuple of the model
@@ -63,7 +62,7 @@ def vgg_cifar10(input_shape=(32, 32, 3),
             * '2' through '8' implements n-bit weights where n is from 2-8 bits.
 
     Returns:
-        tf.keras.Model: a quantized Keras model for vgg/cifar10
+        tf.keras.Model: a Keras model for VGG/CIFAR-10
     """
     # Overrides input weight quantization if None
     if input_weight_quantization is None:
