@@ -34,6 +34,7 @@ from .imagenet.model_mobilenet_edge import mobilenet_edge_imagenet
 from .detection.model_yolo import yolo_base
 from .dvs.model_convtiny_handy import convtiny_dvs_handy
 from .dvs.model_convtiny_gesture import convtiny_dvs_gesture
+from .cwru.model_convtiny import convtiny_cwru
 
 
 def main():
@@ -140,6 +141,7 @@ def main():
                            default=None,
                            help="The base MobileNet weights to use for \
                             transfer learning.")
+    csp.add_parser("convtiny_cwru", help="A Convtiny CWRU model for akida")
     args = parser.parse_args()
     if args.action == "create":
         model_path = args.save_model
@@ -176,6 +178,8 @@ def main():
                               alpha=args.alpha)
             if args.base_weights is not None:
                 model.load_weights(args.base_weights, by_name=True)
+        elif args.model == "convtiny_cwru":
+            model = convtiny_cwru()
         # No need for default behaviour as the command-line parser only accepts
         # valid model types
         if model_path is None:
