@@ -72,7 +72,16 @@ class MapEvaluation(tf.keras.callbacks.Callback):
         self._is_keras_model = is_keras_model
 
     def on_epoch_end(self, epoch, logs=None):
+        """ Keras callback called at the end of an epoch.
 
+        Args:
+            epoch (int): index of epoch.
+            logs (dict, optional): metric results for this training epoch, and
+                for the validation epoch if validation is performed. Validation
+                result keys are prefixed with val. For training epoch, the
+                values of the Model’s metrics are returned.
+                Example : {‘loss’: 0.2, ‘acc’: 0.7}. Defaults to None.
+        """
         if epoch % self._period == 0 and self._period != 0:
             _map, average_precisions = self.evaluate_map()
             print('\n')
