@@ -14,12 +14,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Processing tools for YOLO data handling.
+"""
 
 import os
 
+import xml.etree.ElementTree as et
 import numpy as np
 import tensorflow as tf
-import xml.etree.ElementTree as et
 
 
 class BoundingBox:
@@ -82,13 +85,10 @@ class BoundingBox:
             if x3 < x1:
                 if x4 < x1:
                     return 0
-                else:
-                    return min(x2, x4) - x1
-            else:
-                if x2 < x3:
-                    return 0
-                else:
-                    return min(x2, x4) - x3
+                return min(x2, x4) - x1
+            if x2 < x3:
+                return 0
+            return min(x2, x4) - x3
 
         intersect_w = _interval_overlap([self.x1, self.x2],
                                         [other.x1, other.x2])
@@ -214,21 +214,19 @@ def decode_output(output,
     for c in range(nb_classes):
         sorted_indices = list(
             reversed(np.argsort([box.classes[c] for box in boxes])))
-        for i in range(len(sorted_indices)):
-            index_i = sorted_indices[i]
-
+        for ind, index_i in enumerate(sorted_indices):
             if boxes[index_i].classes[c] == 0:
                 continue
-            else:
-                for j in range(i + 1, len(sorted_indices)):
-                    index_j = sorted_indices[j]
 
-                    # filter out redundant boxes (same class and overlapping too
-                    # much)
-                    if (boxes[index_i].iou(boxes[index_j]) >= nms_threshold
-                       ) and (c == boxes[index_i].get_label()) and (
-                           c == boxes[index_j].get_label()):
-                        boxes[index_j].score = 0
+            for j in range(ind + 1, len(sorted_indices)):
+                index_j = sorted_indices[j]
+
+                # filter out redundant boxes (same class and overlapping too
+                # much)
+                if (boxes[index_i].iou(boxes[index_j]) >= nms_threshold) and (
+                        c == boxes[index_i].get_label()) and (
+                            c == boxes[index_j].get_label()):
+                    boxes[index_j].score = 0
 
     # remove the boxes which are less likely than a obj_threshold
     boxes = [box for box in boxes if box.get_score() > obj_threshold]
@@ -319,7 +317,7 @@ def parse_voc_annotations(gt_folder, image_folder, file_path, labels):
                 if len(box) == 5:
                     data["boxes"].append(box)
 
-        if len(data["boxes"]):
+        if len(data["boxes"]) != 0:
             all_data.append(data)
 
     return all_data
@@ -386,7 +384,7 @@ def parse_widerface_annotations(gt_file, image_folder):
                     }
                     data["boxes"].append(box)
 
-            if len(data["boxes"]):
+            if len(data["boxes"]) != 0:
                 all_data.append(data)
 
         return all_data
