@@ -14,8 +14,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Training script for YOLO models.
+"""
 
-# Training script for YOLO models
 import os
 import argparse
 import pickle
@@ -33,6 +35,19 @@ from .batch_generator import BatchGenerator
 
 
 def compile_model(model_path, anchors, tune, freeze, num_classes, batch_size):
+    """ Loads and compiles the model.
+
+    Args:
+        model_path (str): path of the model to load and compile
+        anchors (list): list of anchors
+        tune (bool): True if tuning, False if training
+        freeze (bool): enables freezing of the MobileNet base layers
+        num_classes (int): the number of classes
+        batch_size (int): the batch size
+
+    Returns:
+        tuple: the loaded model and the grid size parameter of the model
+    """
     nb_box = len(anchors)
 
     # Load the source model
@@ -75,6 +90,24 @@ def compile_model(model_path, anchors, tune, freeze, num_classes, batch_size):
 
 def train(model_path, train_data, valid_data, anchors, labels, obj_threshold,
           nms_threshold, epochs, tune, freeze, batch_size):
+    """ Trains the model.
+
+    Args:
+        model_path (str): path of the model to train
+        train_data (dict): training data
+        valid_data (dict): validation data
+        anchors (list): list of anchors
+        labels (list): list of labels
+        obj_threshold (float): confidence threshold for a box
+        nms_threshold (float): non-maximal supression threshold
+        epochs (int): the number of epochs
+        tune (bool): True if tuning, False if training
+        freeze (bool): enables freezing of the MobileNet base layers
+        batch_size (int): the batch size
+
+    Returns:
+        tf.Keras.Model: the trained model
+    """
     TRAIN_TIMES = 10
 
     # Compile model
@@ -130,7 +163,17 @@ def train(model_path, train_data, valid_data, anchors, labels, obj_threshold,
 
 def evaluate(model_path, valid_data, anchors, labels, obj_threshold,
              nms_threshold, batch_size):
+    """ Evaluates model performances.
 
+    Args:
+        model_path (str): path of the model to evaluate
+        valid_data (dict): evaluation data
+        anchors (list): list of anchors
+        labels (list): list of labels
+        obj_threshold (float): confidence threshold for a box
+        nms_threshold (float): non-maximal supression threshold
+        batch_size (int): the batch size
+    """
     # Compile model
     model, _ = compile_model(model_path, anchors, True, False, len(labels),
                              batch_size)
@@ -151,6 +194,8 @@ def evaluate(model_path, valid_data, anchors, labels, obj_threshold,
 
 
 def main():
+    """ Entry point for script and CLI usage.
+    """
     parser = argparse.ArgumentParser()
     parser.add_argument("-d",
                         "--data",
