@@ -421,3 +421,35 @@ def mobilenet_cats_vs_dogs_pretrained():
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
+
+
+def mobilenet_imagenette_pretrained(alpha=1.0):
+    """
+    Helper method to retrieve a `mobilenet_imagenet` model that was trained on
+    Imagenette dataset.
+
+    Args:
+        alpha (float): width of the model.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    if alpha == 1.0:
+        model_name = 'mobilenet_imagenette_224_iq8_wq4_aq4.h5'
+        file_hash = '986c725cd26163d7ccaee01eee6e6b6c4e2a9eab2f4787fa8b4be00177ac8a8e'
+    elif alpha == 0.5:
+        model_name = 'mobilenet_imagenette_224_alpha_50_iq8_wq4_aq4.h5'
+        file_hash = '4f67e310a71e0bb002f61c429bf3400bc8ae22948f708049e8a0d161c4743152'
+    elif alpha == 0.25:
+        model_name = 'mobilenet_imagenette_224_alpha_25_iq8_wq4_aq4.h5'
+        file_hash = '10e40aa671f757c9b916b141660f11655b26ea164a4cbc4927154ac077d88058'
+    else:
+        raise ValueError(
+            f"Requested model with alpha={alpha} is not available.")
+
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
