@@ -241,3 +241,43 @@ def vgg_melanoma_pretrained():
                           file_hash=file_hash,
                           cache_subdir='models')
     return load_quantized_model(model_path)
+
+
+def vgg_odir5k_pretrained():
+    """
+    Helper method to retrieve a `vgg_imagenet` model that was trained on
+    ODIR-5K dataset.
+
+    The model focuses on the following classes that are a part of the original
+    dataset: normal, cataract, AMD (age related macular degeneration) and
+    pathological myopia.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'vgg11_odir5k_iq8_wq4_aq4.h5'
+    file_hash = 'cb51a5dd2297141f9056d2ec0fbef9d10fbb75fd6f3b38358d8ce8c87f306abb'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
+
+
+def vgg_retinal_oct_pretrained():
+    """
+    Helper method to retrieve a `vgg_imagenet` model that was trained on
+    retinal OCT dataset.
+
+    Returns:
+        tf.keras.Model: a Keras Model instance.
+
+    """
+    model_name = 'vgg11_retinal_oct_iq8_wq4_aq4.h5'
+    file_hash = '6f013df344564190ca6d3278f70470f43456590c5059e7b584ac64193591b670'
+    model_path = get_file(fname=model_name,
+                          origin=BASE_WEIGHT_PATH + model_name,
+                          file_hash=file_hash,
+                          cache_subdir='models')
+    return load_quantized_model(model_path)
