@@ -367,7 +367,7 @@ def input_fn(is_training,
     )
 
 
-def _decode_crop_and_flip(image_buffer, bbox, num_channels):
+def _decode_crop_and_flip(image_buffer, bbox, num_channels, decode=True):
     """Crops the given image to a random part of the image, and randomly flips.
 
   We use the fused decode_and_crop op, which performs better than the two ops
@@ -380,6 +380,7 @@ def _decode_crop_and_flip(image_buffer, bbox, num_channels):
       where each coordinate is [0, 1) and the coordinates are arranged as
       [ymin, xmin, ymax, xmax].
     num_channels: Integer depth of the image buffer for decoding.
+    decode: whether to decode the image or not
 
   Returns:
     3-D tensor with cropped image.
@@ -392,8 +393,14 @@ def _decode_crop_and_flip(image_buffer, bbox, num_channels):
     # allowed range of aspect ratios, sizes and overlap with the human-annotated
     # bounding box. If no box is supplied, then we assume the bounding box is
     # the entire image.
+
+    if decode:
+        shape = tf.image.extract_jpeg_shape(image_buffer)
+    else:
+        shape = tf.shape(image_buffer)
+
     sample_distorted_bounding_box = tf.image.sample_distorted_bounding_box(
-        tf.image.extract_jpeg_shape(image_buffer),
+        shape,
         bounding_boxes=bbox,
         min_object_covered=0.1,
         aspect_ratio_range=[0.75, 1.33],
@@ -402,16 +409,20 @@ def _decode_crop_and_flip(image_buffer, bbox, num_channels):
         use_image_if_no_bounding_boxes=True)
     bbox_begin, bbox_size, _ = sample_distorted_bounding_box
 
-    # Reassemble the bounding box in the format the crop op requires.
-    offset_y, offset_x, _ = tf.unstack(bbox_begin)
-    target_height, target_width, _ = tf.unstack(bbox_size)
-    crop_window = tf.stack([offset_y, offset_x, target_height, target_width])
+    if decode:
+        # Reassemble the bounding box in the format the crop op requires.
+        offset_y, offset_x, _ = tf.unstack(bbox_begin)
+        target_height, target_width, _ = tf.unstack(bbox_size)
+        crop_window = tf.stack(
+            [offset_y, offset_x, target_height, target_width])
 
-    # Use the fused decode and crop op here, which is faster than each in
-    # series.
-    cropped = tf.image.decode_and_crop_jpeg(image_buffer,
-                                            crop_window,
-                                            channels=num_channels)
+        # Use the fused decode and crop op here, which is faster than each in
+        # series.
+        cropped = tf.image.decode_and_crop_jpeg(image_buffer,
+                                                crop_window,
+                                                channels=num_channels)
+    else:
+        cropped = tf.slice(image_buffer, bbox_begin, bbox_size)
 
     # Flip to add a little more random distortion in.
     cropped = tf.image.random_flip_left_right(cropped)
@@ -656,7 +667,8 @@ def preprocess_image(image_buffer,
                      num_channels,
                      is_training=False,
                      alpha=128.,
-                     beta=128.):
+                     beta=128.,
+                     decode=True):
     """Preprocesses the given image.
 
   Preprocessing includes decoding, cropping, and resizing for both training
@@ -673,20 +685,24 @@ def preprocess_image(image_buffer,
     num_channels: Integer depth of the image buffer for decoding.
     is_training: `True` if we're preprocessing the image for training and
       `False` otherwise.
+    decode: whether to decode the image or not
 
   Returns:
     A preprocessed image.
   """
     if is_training:
         # For training, we want to randomize some of the distortions.
-        image = _decode_crop_and_flip(image_buffer, bbox, num_channels)
+        image = _decode_crop_and_flip(image_buffer, bbox, num_channels, decode)
         image = _resize_image(image, output_height, output_width)
         # this could improve things but we skip it for now -- KDC
         #image = _random_distort_color(image)
     else:
         # For validation, we want to decode, resize, then just crop the middle.
+        if decode:
+            image = tf.image.decode_jpeg(image_buffer, channels=num_channels)
+        else:
+            image = image_buffer
         resize_min = int(np.round(max(output_height, output_width) * 1.143))
-        image = tf.image.decode_jpeg(image_buffer, channels=num_channels)
         image = _aspect_preserving_resize(image, resize_min)
         image = _central_crop(image, output_height, output_width)
 
