@@ -77,8 +77,8 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
             * '0' implements floating point 32-bit activations.
             * '1' through '8' implements n-bit weights where n is from 2-8 bits.
 
-    Returns
-        tf.keras.Model: a quantized Keras model for MobileNet/KWS
+    Returns:
+        tf.keras.Model: a Keras model for MobileNet/KWS
     """
     # Overrides input weight quantization if None
     if input_weight_quantization is None:
