@@ -12,11 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-"""Model definitions for simple speech recognition.
+"""
+Model definitions for simple speech recognition.
 
 Brainchip information:
         - Original file: https://github.com/tensorflow/tensorflow/tree/master/tensorflow/examples/speech_commands
 """
+
 import hashlib
 import math
 import os.path
@@ -25,12 +27,12 @@ import re
 import sys
 import tarfile
 import glob
+import urllib
 
 import numpy as np
-import urllib
 import tensorflow as tf
 
-from tensorflow.python.ops import gen_audio_ops as audio_ops
+from tensorflow.python.ops import gen_audio_ops as audio_ops  # pylint: disable=no-name-in-module
 
 MAX_NUM_WAVS_PER_CLASS = 2**27 - 1  # ~134M
 SILENCE_LABEL = '_silence_'
@@ -140,7 +142,7 @@ def which_set(filename, validation_percentage, testing_percentage):
     return result
 
 
-class AudioProcessor(object):
+class AudioProcessor():
     """Handles loading, partitioning, and preparing audio training data."""
 
     def __init__(self,
@@ -172,7 +174,8 @@ class AudioProcessor(object):
             self.prepare_background_data()
         self.prepare_processing_graph()
 
-    def maybe_download_and_extract_dataset(self, data_url, dest_directory):
+    @staticmethod
+    def maybe_download_and_extract_dataset(data_url, dest_directory):
         """Download and extract data set tar file.
 
     If the data set we're using doesn't already exist, this function
@@ -202,11 +205,11 @@ class AudioProcessor(object):
             try:
                 filepath, _ = urllib.request.urlretrieve(
                     data_url, filepath, _progress)
-            except:
+            except Exception as e:
                 raise RuntimeError(
                     f"Failed to download URL: {data_url} to folder: "
                     f"{filepath}\nPlease make sure you have enough free"
-                    f" space and an internet connection")
+                    f" space and an internet connection") from e
             print()
             statinfo = os.stat(filepath)
             print(
@@ -253,15 +256,16 @@ class AudioProcessor(object):
         for wav_path in glob.glob(search_path):
             _, word = os.path.split(os.path.dirname(wav_path))
             word = word.lower()
-            # Treat the '_background_noise_' folder as a special case, since we expect
-            # it to contain long audio samples we mix in to improve training.
+            # Treat the '_background_noise_' folder as a special case, since we
+            # expect it to contain long audio samples we mix in to improve
+            # training.
             if word == BACKGROUND_NOISE_DIR_NAME:
                 continue
             all_words[word] = True
             set_index = which_set(wav_path, validation_percentage,
                                   testing_percentage)
-            # If it's a known class, store its detail, otherwise add it to the list
-            # we'll use to train the unknown label.
+            # If it's a known class, store its detail, otherwise add it to the
+            # list we'll use to train the unknown label.
             if word in wanted_words_index:
                 self.data_index[set_index].append({
                     'label': word,
@@ -279,8 +283,8 @@ class AudioProcessor(object):
                 raise Exception('Expected to find ' + wanted_word +
                                 ' in labels but only found ' +
                                 ', '.join(all_words.keys()))
-        # We need an arbitrary file to load as the input for the silence samples.
-        # It's multiplied by zero later, so the content doesn't matter.
+        # We need an arbitrary file to load as the input for the silence
+        # samples. It's multiplied by zero later, so the content doesn't matter.
         silence_wav_path = self.data_index['training'][0]['file']
         for set_index in ['validation', 'testing', 'training']:
             set_size = len(self.data_index[set_index])
@@ -309,7 +313,8 @@ class AudioProcessor(object):
         self.word_to_index[SILENCE_LABEL] = SILENCE_INDEX
 
     def prepare_background_data(self):
-        """Searches a folder for background noise audio, and loads it into memory.
+        """Searches a folder for background noise audio, and loads it into
+         memory.
 
     It's expected that the background audio samples will be in a subdirectory
     named '_background_noise_' inside the 'data_dir' folder, as .wavs that match
@@ -341,6 +346,7 @@ class AudioProcessor(object):
         if not self.background_data:
             raise Exception('No background wav files were found in ' +
                             search_path)
+        return []
 
     def prepare_processing_graph(self):
         """Builds a TensorFlow graph to apply the input distortions.
@@ -364,29 +370,33 @@ class AudioProcessor(object):
             scaled_foreground = tf.multiply(wav_decoder.audio,
                                             foreground_volume)
             # Shift the sample's start position, and pad any gaps with zeros.
-            padded_foreground = tf.pad(tensor=scaled_foreground,
-                                       paddings=time_shift_padding,
-                                       mode='CONSTANT')
+            # pylint must be disabled here as it incorrectly identifies tf API
+            # as explained in
+            # https://github.com/tensorflow/tensorflow/issues/43038.
+            # pylint: disable=no-value-for-parameter
+            padded_foreground = tf.pad(scaled_foreground, time_shift_padding)
             sliced_foreground = tf.slice(padded_foreground, time_shift_offset,
                                          [desired_samples, -1])
             # Mix in background noise.
             background_mul = tf.multiply(background_data, background_volume)
             background_add = tf.add(background_mul, sliced_foreground)
             background_clamp = tf.clip_by_value(background_add, -1.0, 1.0)
-            # Run the spectrogram and MFCC ops to get a 2D 'fingerprint' of the audio.
+            # Run the spectrogram and MFCC ops to get a 2D 'fingerprint' of the
+            # audio.
             spectrogram = audio_ops.audio_spectrogram(
                 background_clamp,
                 window_size=model_settings['window_size_samples'],
                 stride=model_settings['window_stride_samples'],
                 magnitude_squared=True)
-            # The number of buckets in each FFT row in the spectrogram will depend on
-            # how many input samples there are in each window. This can be quite
-            # large, with a 160 sample window producing 127 buckets for example. We
-            # don't need this level of detail for classification, so we often want to
-            # shrink them down to produce a smaller result. That's what this section
-            # implements. One method is to use average pooling to merge adjacent
-            # buckets, but a more sophisticated approach is to apply the MFCC
-            # algorithm to shrink the representation.
+            # The number of buckets in each FFT row in the spectrogram will
+            # depend on how many input samples there are in each window. This
+            # can be quite large, with a 160 sample window producing 127 buckets
+            # for example. We don't need this level of detail for
+            # classification, so we often want to shrink them down to produce a
+            # smaller result. That's what this section implements. One method is
+            # to use average pooling to merge adjacent buckets, but a more
+            # sophisticated approach is to apply the MFCC algorithm to shrink
+            # the representation.
             output = audio_ops.mfcc(
                 spectrogram,
                 wav_decoder.sample_rate,
@@ -438,8 +448,8 @@ class AudioProcessor(object):
         desired_samples = self.model_settings['desired_samples']
         use_background = self.background_data and (mode == 'training')
         pick_deterministically = (mode != 'training')
-        # Use the processing graph we created earlier to repeatedly to generate the
-        # final output sample data we'll use in training.
+        # Use the processing graph we created earlier to repeatedly to generate
+        # the final output sample data we'll use in training.
         for i in range(offset, offset + sample_count):
             # Pick which audio sample to use.
             if how_many == -1 or pick_deterministically:
@@ -496,7 +506,8 @@ class AudioProcessor(object):
                                                         dtype=tf.float32)
             input_dict['background_volume'] = tf.constant(background_volume,
                                                           dtype=tf.float32)
-            # If we want silence, mute out the main sample but leave the background.
+            # If we want silence, mute out the main sample but leave the
+            # background.
             if sample['label'] == SILENCE_LABEL:
                 input_dict['foreground_volume'] = tf.constant(0.0)
             else:
@@ -548,8 +559,8 @@ class AudioProcessor(object):
                                    background_volume_range,
                                    time_shift,
                                    num_augmented_samples=1):
-        """Applies the feature transformation process to a wav audio file, adding
-    data augmentation (background noise and time shifting).
+        """Applies the feature transformation process to a wav audio file,
+         adding data augmentation (background noise and time shifting).
 
     Args:
       wav_filename (str): The path to the input audio file.
