@@ -14,10 +14,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ******************************************************************************
+"""
+Layers blocks definitions.
+"""
 
 # Keras Imports
-from tensorflow.keras.layers import BatchNormalization, ReLU
-from tensorflow.keras.layers import (Conv2D, SeparableConv2D, Dense, MaxPool2D,
+from tensorflow.keras.layers import (BatchNormalization, ReLU, Conv2D,
+                                     SeparableConv2D, Dense, MaxPool2D,
                                      AvgPool2D, GlobalAvgPool2D)
 
 
@@ -45,15 +48,14 @@ def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
         return MaxPool2D(pool_size=pool_size,
                          padding=padding,
                          name=layer_base_name + '_maxpool')(x)
-    elif pooling_type == 'avg':
+    if pooling_type == 'avg':
         return AvgPool2D(pool_size=pool_size,
                          padding=padding,
                          name=layer_base_name + '_avgpool')(x)
-    elif pooling_type == 'global_avg':
+    if pooling_type == 'global_avg':
         return GlobalAvgPool2D(name=layer_base_name + '_global_avg')(x)
-    else:
-        raise ValueError("'pooling_type' argument must be 'max', "
-                         "'avg' or 'global_avg'.")
+    raise ValueError("'pooling_type' argument must be 'max', "
+                     "'avg' or 'global_avg'.")
 
 
 def conv_block(inputs,
