@@ -15,9 +15,9 @@
 # limitations under the License.
 # ******************************************************************************
 """
- Toolset to load UTKFace preprocessed dataset.
+Toolset to load UTKFace preprocessed dataset.
 
- Original files: https://susanqq.github.io/UTKFace/
+Original files: https://susanqq.github.io/UTKFace/
 
 """
 
@@ -39,10 +39,10 @@ def _load_images(root_path):
     num_files = len(file_list)
 
     x = np.zeros((num_files, 32, 32, 3))
-    for id in range(num_files):
-        raw_image = tf.io.read_file(os.path.join(root_path, file_list[id]))
+    for i in range(num_files):
+        raw_image = tf.io.read_file(os.path.join(root_path, file_list[i]))
         image = tf.image.decode_jpeg(raw_image, channels=3)
-        x[id, :, :, :] = np.expand_dims(image.numpy(), axis=0)
+        x[i, :, :, :] = np.expand_dims(image.numpy(), axis=0)
 
     y = np.array([[i.split('_')[0]] for i in file_list]).astype('int8')
 
